import { Resource, ResourceProps } from 'aws-cdk-lib';
import { Schedule } from 'aws-cdk-lib/aws-events';
import { CfnTrigger } from 'aws-cdk-lib/aws-glue';
import { Construct } from 'constructs';
import { Workflow } from './workflow';
export declare enum PredicateOperator {
    AND = "AND",
    OR = "OR"
}
export declare enum TriggerType {
    CONDITIONAL = "CONDITIONAL",
    EVENT = "EVENT",
    ON_DEMAND = "ON_DEMAND",
    SCHEDULED = "SCHEDULED"
}
export interface ITriggerAction {
    bind(trigger: Trigger): CfnTrigger.ActionProperty;
}
export interface ITriggerPredicate {
    bind(trigger: Trigger): CfnTrigger.ConditionProperty;
}
/**
 * Configuration for the Glue Trigger resource.
 */
export interface TriggerProps extends ResourceProps {
    /**
     * A list of actions initiated by this trigger.
     *
     * @see [AWS::Glue::Trigger Action](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-glue-trigger-action.html)
     */
    readonly actions?: ITriggerAction[];
    /**
     * A description for the Trigger
     */
    readonly description?: string;
    /**
     * A name for the Trigger
     */
    readonly name?: string;
    /**
     * A list of conditions predicating the trigger, determining when it will fire
     *
     * @see [AWS::Glue::Trigger Predicate](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-glue-trigger-predicate.html)
     */
    readonly predicateConditions?: ITriggerPredicate[];
    /**
     * Operator for chaining predicate conditions (AND/OR)
     */
    readonly predicateOperator?: PredicateOperator;
    /**
     * A cron expression used to specify the schedule.
     *
     * @see [AWS::Glue::Trigger](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-glue-trigger.html#cfn-glue-trigger-schedule)
     */
    readonly schedule?: Schedule;
    /**
     * Set to true to start SCHEDULED and CONDITIONAL triggers when created. True is not supported for ON_DEMAND triggers.
     *
     * @see [AWS::Glue::Trigger](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-glue-trigger.html#cfn-glue-trigger-startoncreation)
     */
    readonly startOnCreation?: boolean;
    /**
     * The type of trigger that this is.
     *
     * @see [AWS::Glue::Trigger](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-glue-trigger.html#cfn-glue-trigger-type)
     */
    readonly type: TriggerType;
    /**
     * Workflow object the Trigger should be attached to
     */
    readonly workflow?: Workflow;
}
export declare class Trigger extends Resource {
    private readonly _actions;
    private readonly _predicates;
    /**
      * {@link TriggerProps.description}
      */
    readonly description?: string;
    /**
      * {@link TriggerProps.name}
      */
    readonly name?: string;
    /**
      * {@link TriggerProps.predicateOperator:}
      */
    readonly predicateOperator: PredicateOperator;
    /**
      * {@link TriggerProps.schedule}
      */
    readonly schedule?: Schedule;
    /**
      * {@link TriggerProps.startOnCreation}
      */
    readonly startOnCreation?: boolean;
    /**
      * {@link TriggerProps.type:}
      */
    readonly type: TriggerType;
    /**
      * {@link TriggerProps.workflow}
      */
    readonly workflow?: Workflow;
    readonly resource: CfnTrigger;
    readonly workflowArn: string;
    readonly workflowName: string;
    /**
       * Creates a new instance of the Trigger class.
       *
       * @param scope A CDK Construct that will serve as this stack's parent in the construct tree.
       * @param id A name to be associated with the stack and used in resource naming. Must be unique
       * within the context of 'scope'.
       * @param props Arguments related to the configuration of the resource.
       */
    constructor(scope: Construct, id: string, props: TriggerProps);
    addAction(action: ITriggerAction): Trigger;
    addPredicate(predicate: ITriggerPredicate): Trigger;
}
